==> spyder-screencast-0.0.15.tar.gz: spyder-screencast-0.0.15/README.md <==
# spyder-screencast

screencast plugin for spyder 5

[![GitHub](https://img.shields.io/github/license/Semi-ATE/spyder-screencast?color=black)](https://github.com/Semi-ATE/spyder-screencast/blob/main/LICENSE)
[![Conda](https://img.shields.io/conda/pn/conda-forge/spyder-screencast?color=black)](https://anaconda.org/conda-forge/spyder-screencast)
![Supported Python versions](https://img.shields.io/badge/python-%3E%3D3.6-black)

[![CI](https://github.com/Semi-ATE/spyder-screencast/workflows/CI/badge.svg?branch=main)](https://github.com/Semi-ATE/spyder-screencast/actions?query=workflow%3ACI)
[![CD](https://github.com/Semi-ATE/spyder-screencast/workflows/CD/badge.svg)](https://github.com/Semi-ATE/spyder-screencast/actions?query=workflow%3ACD)

[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/Semi-ATE/spyder-screencast?color=blue&label=GitHub&sort=semver)](https://github.com/Semi-ATE/spyder-screencast/releases/latest)
[![GitHub commits since latest release (by date)](https://img.shields.io/github/commits-since/Semi-ATE/spyder-screencast/latest)](https://github.com/Semi-ATE/spyder-screencast)
[![PyPI](https://img.shields.io/pypi/v/spyder-screencast?color=blue&label=PyPI)](https://pypi.org/project/spyder-screencast/)
[![Conda (channel only)](https://img.shields.io/conda/vn/conda-forge/spyder-screencast?color=blue&label=conda-forge)](https://anaconda.org/conda-forge/spyder-screencast)
[![conda-forge feedstock](https://img.shields.io/github/issues-pr/conda-forge/spyder-screencast-feedstock?label=feedstock)](https://github.com/conda-forge/spyder-screencast-feedstock)

![PyPI - Downloads](https://img.shields.io/pypi/dm/spyder-screencast?color=g&label=PyPI%20downloads)
![Conda](https://img.shields.io/conda/dn/conda-forge/spyder-screencast?color=g&label=conda-forge%20downloads)

[![GitHub issues](https://img.shields.io/github/issues/Semi-ATE/spyder-screencast)](https://github.com/Semi-ATE/spyder-screencast/issues)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/Semi-ATE/spyder-screencast)](https://github.com/Semi-ATE/spyder-screencast/pulls)

`spyder-screencast` is based on [QScreenCast](https://github.com/Semi-ATE/QScreenCast)

## Installation

### conda/mamba (preferred)

```bash
(myenv) me@mybox:~$ conda install -c conda-forge spyder-screencast 
```

**Note:** `spyder-screencast` depends on `spyder 5` and `QScreenCast`, both will be installed with the above command (if not already installed)

### pip

Prior to installing `spyder-screencast`, you need to install [ffmpeg](https://www.ffmpeg.org/download.html#build-windows)  on your system somehow.

```bash
me@mybox:~$ pip install spyder-screencast
```

## Usage

see: [QScreenCast](https://github.com/Semi-ATe/QScreenCast)

==> spyder-screencast-0.0.19.tar.gz: spyder-screencast-0.0.19/README.md <==
# spyder-screencast

`spyder-screencast` is merely a wrapper around [QScreenCast](https://github.com/Semi-ATE/QScreenCast) to turn it into a screencast plugin for [Spyder](https://www.spyder-ide.org/) >= 5.1.1

[![GitHub](https://img.shields.io/github/license/Semi-ATE/spyder-screencast?color=black)](https://github.com/Semi-ATE/spyder-screencast/blob/main/LICENSE)
[![Conda](https://img.shields.io/conda/pn/conda-forge/spyder-screencast?color=black)](https://anaconda.org/conda-forge/spyder-screencast)
![Supported Python versions](https://img.shields.io/badge/python-%3E%3D3.6-black)

[![CI](https://github.com/Semi-ATE/spyder-screencast/workflows/CI/badge.svg?branch=main)](https://github.com/Semi-ATE/spyder-screencast/actions?query=workflow%3ACI)
[![CD](https://github.com/Semi-ATE/spyder-screencast/workflows/CD/badge.svg)](https://github.com/Semi-ATE/spyder-screencast/actions?query=workflow%3ACD)

[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/Semi-ATE/spyder-screencast?color=blue&label=GitHub)](https://github.com/Semi-ATE/spyder-screencast/releases/latest)
[![GitHub commits since latest release (by date)](https://img.shields.io/github/commits-since/Semi-ATE/spyder-screencast/latest)](https://github.com/Semi-ATE/spyder-screencast)
[![PyPI](https://img.shields.io/pypi/v/spyder-screencast?color=blue&label=PyPI)](https://pypi.org/project/spyder-screencast/)
[![Conda (channel only)](https://img.shields.io/conda/vn/conda-forge/spyder-screencast?color=blue&label=conda-forge)](https://anaconda.org/conda-forge/spyder-screencast)
[![conda-forge feedstock](https://img.shields.io/github/issues-pr/conda-forge/spyder-screencast-feedstock?label=feedstock)](https://github.com/conda-forge/spyder-screencast-feedstock)

![PyPI - Downloads](https://img.shields.io/pypi/dm/spyder-screencast?color=g&label=PyPI%20downloads)
![Conda](https://img.shields.io/conda/dn/conda-forge/spyder-screencast?color=g&label=conda-forge%20downloads)

[![GitHub issues](https://img.shields.io/github/issues/Semi-ATE/spyder-screencast)](https://github.com/Semi-ATE/spyder-screencast/issues)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/Semi-ATE/spyder-screencast)](https://github.com/Semi-ATE/spyder-screencast/pulls)


## Installation

### conda/mamba (preferred)

```bash
(myenv) me@mybox:~$ conda install -c conda-forge spyder-screencast 
```

**Note:** `spyder-screencast` depends on `spyder >= 5.1.1` and `QScreenCast`, both will be installed with the above command (if not already installed)

### pip

Prior to installing `spyder-screencast`, you need to install [ffmpeg](https://www.ffmpeg.org/download.html#build-windows)  on your system somehow.

```bash
me@mybox:~$ pip install spyder-screencast
```

## Usage

see: [QScreenCast](https://github.com/Semi-ATe/QScreenCast)
